@@ -91,6 +91,7 @@ __all__ = (
     "GetOpsSummaryPaginatorName",
     "GetParameterHistoryPaginatorName",
     "GetParametersByPathPaginatorName",
+    "GetResourcePoliciesPaginatorName",
     "InstanceInformationFilterKeyType",
     "InstancePatchStateOperatorTypeType",
     "InventoryAttributeDataTypeType",
@@ -312,6 +313,7 @@ GetInventorySchemaPaginatorName = Literal["get_inventory_schema"]
 GetOpsSummaryPaginatorName = Literal["get_ops_summary"]
 GetParameterHistoryPaginatorName = Literal["get_parameter_history"]
 GetParametersByPathPaginatorName = Literal["get_parameters_by_path"]
+GetResourcePoliciesPaginatorName = Literal["get_resource_policies"]
 InstanceInformationFilterKeyType = Literal[
     "ActivationIds",
     "AgentVersion",
@@ -380,6 +382,7 @@ OpsItemDataTypeType = Literal["SearchableString", "String"]
 OpsItemEventFilterKeyType = Literal["OpsItemId"]
 OpsItemEventFilterOperatorType = Literal["Equal"]
 OpsItemFilterKeyType = Literal[
+    "AccountId",
     "ActualEndTime",
     "ActualStartTime",
     "AutomationId",
@@ -761,6 +764,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -781,6 +785,7 @@ ServiceName = Literal[
     "sagemaker-featurestore-runtime",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
@@ -803,6 +808,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssmsap",
     "sso",
     "sso-admin",
     "sso-oidc",
@@ -879,6 +885,7 @@ PaginatorName = Literal[
     "get_ops_summary",
     "get_parameter_history",
     "get_parameters_by_path",
+    "get_resource_policies",
     "list_association_versions",
     "list_associations",
     "list_command_invocations",
@@ -906,8 +913,10 @@ RegionName = Literal[
     "ap-southeast-3",
     "ca-central-1",
     "eu-central-1",
+    "eu-central-2",
     "eu-north-1",
     "eu-south-1",
+    "eu-south-2",
     "eu-west-1",
     "eu-west-2",
     "eu-west-3",
